Given a file containing emulator details, reconstruct a collection of emulators.
import_emulator_from_json(filename = NULL, details = NULL)The emulator objects, as a list.
Either a file location of a saved JSON file, or the string corresponding to it
Mainly internal; any already reconstructed emulators and their input data
For data generated from export_emulator_to_json (for example),
emulators are recreated using the specifications therein. For each emulator,
a call is made to emulator_from_data with specified_priors
stipulated (so no retraining is performed, making the reconstruction fast).
The structure of the JSON file used to import is relatively generic, and can be created outside of this package. For examples of the structure, see the code given in the companion export function.
export_emulator_to_json