For models with large numbers of outputs, it may not be useful or meaningful
to emulate every output at every wave; particularly at early waves, the main
effects can often be explained by a small number of model outputs. This
function determines those outputs which contribute most highly to the model
variation across the space.
Two cut-off points for informative outputs are available: max_vars
allows one to limit the number of outputs emulated, while var_cut
will continue to select outputs until a given proportion of variation has
been explained. By default, no maximum number of variables is imposed and
the desired variation explained is 95
The output is a list of two elements: the first, a set of variable names
ordered by variance explained (the first being the most informative); the
second a record of the cumulative variance explained upon inclusion of each
of the outputs.