Learn R Programming

hmer (version 1.6.2)

residual_diag: Emulator Regression Residuals

Description

Plots the emulator residuals.

Usage

residual_diag(emulator, histogram = FALSE, ...)

Value

A set of residuals, standardised by the regression surface residual standard error.

Arguments

emulator

The emulator to consider.

histogram

Should a histogram or a scatter plot be shown? Default: FALSE

...

Any additional arguments (used internally)

Details

An emulator is composed of two parts: a global regression surface, and a local correlation structure. It can sometimes be informative to examine the residuals of the regression surface on the training set, to determine the extent to which the regression surface is being `corrected for' by the correlation structure.

See Also

Other diagnostic functions: analyze_diagnostic(), classification_diag(), comparison_diag(), get_diagnostic(), individual_errors(), standard_errors(), summary_diag(), validation_diagnostics()

Examples

Run this code
residual_diag(SIREmulators$ems$nS)
residual_diag(SIREmulators$ems$nI, TRUE)

Run the code above in your browser using DataLab