Given a collection of emulators corresponding to a wave, we can look at an estimate of
the proportion of points from previous waves that will be accepted at this wave, either
on an emulator-by-emulator basis (to see which outputs are most restrictive) or as an all-wave
determination.
Naturally, such a statement will be an estimate of the restriction on the full space (which will
become more unreliable for higher dimensions), but it can give an order-of-magnitude statement,
or useful comparators between different emulators in a wave.
If no points are provided, the training points for the emulators are used. For best results, a
good number of points should be given: typically one should consider using as many points as one
knows to be in the NROY space (including any validation points, if accessible).