Generates measures for emulator quality
summary_diag(emulator, validation, verbose = interactive())Whether the observed value lies within 3-sigma of the expected value.
The emulator to test
The validation set, consisting of points and output(s)
Should statistics be printed out?
A couple of summary statistics can be generated for emulators, based on their prediction errors on a validation set. This function produces the test statistic for a comparison to a relevant chi-squared distribution, and the similar test statistic for an F-distribution. In both cases, the expectation and standard deviation of the underlying distribution are also provided.
The output of this function is a logical vector stating whether the derived
value lies within 3-sigma of the expected value. In systems where errors are
expected to be correlated, higher weight should be given to the Mahalanobis
measure than the chi-squared measure. Any anomalous results can be investigated
in more depth using the individual_errors function.
Bastos & O'Hagan (2009) <doi:10.1198/TECH.2009.08019>
Other diagnostic functions:
analyze_diagnostic(),
classification_diag(),
comparison_diag(),
get_diagnostic(),
individual_errors(),
residual_diag(),
standard_errors(),
validation_diagnostics()
summary_diag(SIREmulators$ems$nR, SIRSample$validation)
Run the code above in your browser using DataLab