A set of residuals, standardised by the regression surface residual standard error.
Arguments
emulator
The emulator to consider.
histogram
Should a histogram or a scatter plot be shown? Default: FALSE
...
Any additional arguments (used internally)
Details
An emulator is composed of two parts: a global regression surface, and a local
correlation structure. It can sometimes be informative to examine the residuals
of the regression surface on the training set, to determine the extent to which
the regression surface is being `corrected for' by the correlation structure.